pub struct PackagesDb { /* private fields */ }Expand description
Handle to an open spam packages database or autonomous index.
Only the fixed-size bucket index is loaded into memory on construction.
Implementations
Sourceimpl PackagesDb
impl PackagesDb